<?php

if (!defined('ABSPATH')) exit;

class WooCommerce_Shipmate_List_Order_Actions
{

    /**
     * The single instance of WooCommerce_Shipmate_List_Order_Actions.
     * @var    object
     * @access  private
     * @since    1.0.0
     */
    private static $_instance = null;

    /**
     * The main plugin object.
     * @var    object
     * @access  public
     * @since    1.0.0
     */
    public $parent = null;

    /**
     * Prefix for plugin settings.
     * @var     string
     * @access  public
     * @since   1.0.0
     */
    public $base = '';


    /**
     * The shipmate integration class
     * @var     WooCommerce_Shipmate_Integration
     * @access  protected
     * @since   1.0.0
     */
    protected $shipmate_integration = null;

    /**
     * The shipmate service class
     * @var     WooCommerce_Shipmate_Service
     * @access  protected
     * @since   1.0.0
     */
    protected $shipmate_service = null;

    /**
     * The key for post_meta to state an order has been printed
     * @var     WooCommerce_Shipmate_Service
     * @access  protected
     * @since   1.0.0
     */
    protected $printed_meta_key = "_wc_order_printed_with_shipmate";
    protected $tracking_reference_meta_key = "_wc_order_tracking_reference";

    /**
     * Available settings for plugin.
     * @var     array
     * @access  public
     * @since   1.0.0
     */
    public $settings = array();

    public function __construct($parent)
    {

        $this->parent = $parent;

        $this->base = 'wpt_';

        $this->shipmate_integration = new WooCommerce_Shipmate_Integration();
        $this->shipmate_service = new WooCommerce_Shipmate_Service($this->shipmate_integration);

        if (!empty(get_option('shipmate_sender_token', null))) {
            add_filter('bulk_actions-edit-shop_order', array($this, 'add_buttons'));
            add_action('wp_ajax_shipmate_prints', array($this, 'shipmate_prints'));
            add_action('wp_ajax_shipmate_get_orders', array($this, 'shipmate_get_orders'));
        }

    }

    function shipmate_get_orders()
    {
        //Loop through order ids
        $order_ids = $_POST['order_ids'];


        $data = [];
        foreach ($order_ids as $order_id) {
            $disabled = $created_with_shipmate = get_post_meta($order_id, "_wc_order_printed_with_shipmate", true) == 'yes';

            $order = wc_get_order($order_id);

            if (WooCommerce_Shipmate_Integration::version_check('3.0')) {
                $status = $order->get_status();
            } else {
                $status = $order->status;
            }

            $can_print = true;

            $auto_print = get_option("_shipmate_printing_type", 'true') === 'true';


            //If processing stop is on and the order is no processing then can print = false
            if (get_option("_shipmate_process_block") == 'true' && $status !== "processing") {
                $can_print = false;
                //If created with shipmate
            }
            if ($created_with_shipmate && $auto_print) {
                $can_print = true;
            }
            $data[] = [
                'id' => $order_id,
                'disabled' => $disabled,
                'can_print' => $can_print,
                'auto_print' => $auto_print
            ];
        }

        echo json_encode($data);
        die();
    }


    function shipmate_prints()
    {


        $order_id = $_POST['order_id'];
        $order = wc_get_order($order_id);


        $parcelDimensions = [];

        $parcelDimensions['parcel_weights'][] = $_POST['parcel_weight'];
        $parcelDimensions['parcel_lengths'][] = $_POST['parcel_length'];
        $parcelDimensions['parcel_widths'][] = $_POST['parcel_width'];
        $parcelDimensions['parcel_depths'][] = $_POST['parcel_depth'];


        $consignment = new WooCommerce_Shipmate_Consignment($order,
            $parcelDimensions,
            !empty($_POST['delivery_service_key']) ? $_POST['delivery_service_key'] : "",
            !empty($_POST['dispatch_date']) ? $_POST['dispatch_date'] : date('Y-m-d', strtotime('now'))
        );
        // $consignment->set_delivery_service_key(!empty($_POST['delivery_service_key']) ? $_POST['delivery_service_key'] : "");

        $wordpress_user = wp_get_current_user();
        $shipmate_user_id = get_user_meta($wordpress_user->ID, '_shipmate_user_id', true);
        $result = $this->shipmate_service->create_consignment($shipmate_user_id, $consignment->toArray());

        switch ($result->http_code()) {
            case "403":
                $message = sprintf(__('Unable to connect to Shipmate (Invalid Access Token).', 'shipmate'));
                $order->add_order_note($message);
                echo(json_encode(array('success' => false)));
                die();
                break;
            case "400":
                foreach ($result->data() as $key => $error) {
                    $message = sprintf(__('Shipmate error: %s'), $error);
                    $order->add_order_note($message);
                }

                if (get_option("_shipmate_status_failed", "Don\'t Change") != "Don\'t Change") {

                    if (WooCommerce_Shipmate_Integration::version_check('3.0')) {
                        $order->set_status(get_option("_shipmate_status_failed"));
                        $order->save();
                    } else {
                        $order->update_status(get_option("_shipmate_status_failed"));
                    }

                }

                echo(json_encode(array('success' => false)));
                die();
                break;
            case "201":
                foreach ($result->data() as $key => $label) {
                    // if we haven't previously created these parcels, save the tracking reference and dimensions
                    if (get_post_meta($order_id, $this->printed_meta_key, true) != 'yes') {
                        $message = sprintf(__('Shipping Label generated with Tracking Reference %s for %s. (%s - %s)', 'shipmate'), $label->tracking_reference, $label->parcel_reference, $label->carrier, $label->service_name);
                        $order->add_order_note($message);


                        // store the carrier and service used
                        update_post_meta($order_id, '_shipmate_carrier', $label->carrier);
                        update_post_meta($order_id, '_shipmate_service', $label->service_name);

                        // store tracking references / dims in meta for the order
                        add_post_meta($order_id, '_shipmate_parcel_reference', $label->parcel_reference, false);
                        add_post_meta($order_id, '_shipmate_tracking_reference', $label->tracking_reference, false);
                        add_post_meta($order_id, '_shipmate_parcel_weight', $parcelDimensions['parcel_weights'][$key], false);
                        add_post_meta($order_id, '_shipmate_parcel_length', $parcelDimensions['parcel_lengths'][$key], false);
                        add_post_meta($order_id, '_shipmate_parcel_width', $parcelDimensions['parcel_widths'][$key], false);
                        add_post_meta($order_id, '_shipmate_parcel_depth', $parcelDimensions['parcel_depths'][$key], false);

                        if (function_exists('wc_st_add_tracking_number')) {
                            $provider = $this->shipmate_integration->convert_carrier_to_provider($label->carrier);

                            wc_st_add_tracking_number($order_id, $label->tracking_reference, $provider, null, null);
                        }

                        if (get_option("_shipmate_status_success", "Don\'t Change") != "Don\'t Change") {
                            if (WooCommerce_Shipmate_Integration::version_check('3.0')) {
                                $order->set_status(get_option("_shipmate_status_success"));
                                $order->save();
                            } else {
                                $order->update_status(get_option("_shipmate_status_success"));
                            }
                        }
                    }
                }

                update_post_meta($order_id, $this->printed_meta_key, 'yes');
                $message = sprintf(__('Shipping Label' . (count($result->data()) == 1 ? '' : 's') . ' printed with Shipmate by %s.', 'shipmate'), wp_get_current_user()->display_name);
                $order->add_order_note($message);
                echo(json_encode(array('success' => true)));
                die();
                break;
            default:
                die();
                break;
        }
    }


    function add_buttons($actions)
    {
        $auto_print = get_option("_shipmate_printing_type", 'true') === 'true';
        $actions['wc_order_print_label'] = __($auto_print ? 'Print Labels with Shipmate' : 'Generate Shipments with Shipmate', 'shipmate');
        echo(WooCommerce_Shipmate_Orders_Metabox::output());
        return $actions;
    }


    /**
     * Main WooCommerce_Shipmate_Order_Actions Instance
     *
     * Ensures only one instance of WooCommerce_Shipmate_Order_Actions is loaded or can be loaded.
     *
     * @return Main WooCommerce_Shipmate_Order_Actions instance
     * @see WooCommerce_Shipmate()
     * @since 1.0.0
     * @static
     */
    public static function instance($parent)
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self($parent);
        }
        return self::$_instance;
    } // End instance()

    /**
     * Cloning is forbidden.
     *
     * @since 1.0.0
     */
    public function __clone()
    {
        _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->parent->_version);
    } // End __clone()

    /**
     * Unserializing instances of this class is forbidden.
     *
     * @since 1.0.0
     */
    public function __wakeup()
    {
        _doing_it_wrong(__FUNCTION__, __('Cheatin&#8217; huh?'), $this->parent->_version);
    } // End __wakeup()

}
