<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class WooCommerce_Shipmate_Service {

    const STAGING_ENDPOINT = "https://api-staging.shipmate.co.uk";
    const PRODUCTION_ENDPOINT = "https://api.shipmate.co.uk";

    
    const API_VERSION = "v1";

    protected $shipmate_integration = null;
    protected $headers = [
        'Accept: application/json',
        'Content-Type: application/json'
    ];

    /**
     * Constructor function.
     * @access  public
     * @since   1.0.0
     * @return  void
     */
    public function __construct ($integration = null) {
        if($integration) {
            $this->shipmate_integration = $integration;
        } else {
            $this->shipmate_integration = new WooCommerce_Shipmate_Integration();
        }
    }

    public function disconnect() {
        $result = $this->send_request('DELETE', '/woocommerce/v1/integrations', array());
        $this->shipmate_integration->delete();

        return true;
    }

    public function connect($data) {

        $username   = isset($data['wc_settings_shipmate_username']) ? $data['wc_settings_shipmate_username'] : "";
        $password   = isset($data['wc_settings_shipmate_password']) ? $data['wc_settings_shipmate_password'] : "";
        $live       = isset($data['wc_settings_shipmate_live']) ? $data['wc_settings_shipmate_live'] : false;

        $result = $this->send_request('POST', '/woocommerce/v1/integrations', [
            'email' => $username,
            'password' => $password,
            'live' => $live
        ], $live);
        //  die(print_r($result, true));

        return $result;
    }

    public function create_consignment($shipmate_user_id, $consignment_array) {
        $result = $this->send_request('POST', '/woocommerce/v1/print', array_merge(['user_id' => $shipmate_user_id, 'print_on_create' => (get_option("_shipmate_printing_type", 'true') === 'true') ? 'yes' : 'no'], $consignment_array));
        return $result;
    }

    public function users() {
        $result = $this->send_request('GET', '/woocommerce/v1/users', array());
        
        return $result;
    }


    public function packaging_option() {
        $result = $this->send_request('GET', '/woocommerce/v1/packagingOptions', array());
        
        return $result;
    }

    public function cancel_consignment($consignment_reference) {
        $result = $this->send_request('DELETE', '/v1/consignments/' . $consignment_reference, array());

        return $result;
    }

    public function tracking_events($consignment_reference) {
        $result = $this->send_request('GET', '/v1/consignments/' . $consignment_reference . '/events', array());

        return $result;
    }

    public function services() {
        $result = $this->send_request('GET', '/v1/services', array());
        
        return $result;
    }

    protected function send_request($method, $path, $data, $live = null) {

        // Init curl and set up token
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_USERPWD, $this->shipmate_integration->token() . ":");      

        // set options for the correct HTTP Method
        switch($method) {
            case 'GET':
                $path .= http_build_query($data);
                break;
            case 'POST':
                curl_setopt($curl, CURLOPT_POST, true);
                curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($data));
                break;
            case 'PUT': 
                curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'PUT');
                curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($data));
                break;
            case 'DELETE':
                curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'DELETE');
                break;
        }

        // set headers and endpoint
        curl_setopt($curl, CURLOPT_HTTPHEADER, $this->headers);

        $use_live_url = ($live === null) ? $this->shipmate_integration->is_live() : $live;
        if($use_live_url) {    
            curl_setopt($curl, CURLOPT_URL, self::PRODUCTION_ENDPOINT . $path);
        } else {
            curl_setopt($curl, CURLOPT_URL, self::STAGING_ENDPOINT . $path);
        }    
        $response = curl_exec($curl);
        $code = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        

        return new WooCommerce_Shipmate_API_Response($code, $response);
    }
}
