<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class WooCommerce_Shipmate_Address {

	protected $name = "";
	protected $company_name = "";
	protected $telephone = "";
	protected $email = "";
	protected $line_1 = "";
	protected $line_2 = "";
	protected $line_3 = "";
	protected $city = "";
	protected $county = "";
	protected $postcode = "";
	protected $country = "";

	/**
	 * Constructor function.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function __construct ($wc_shipping, $wc_billing) {

        // Decide which phone to use
        // If the shipping address has a phone number, use that
        // Otherwise, use the billing address phone number
        $phone = '';
        if(!array_key_exists('phone', $wc_shipping) || $wc_shipping['phone'] == '') {
            // No phone number in shipping address, use billing address phone number
            $phone = $wc_billing['phone'];
        } else {
            // Phone number in shipping address, use that
            $phone = $wc_shipping['phone'];
        }

		$this->name = 				$wc_shipping['first_name'] . ' ' . $wc_shipping['last_name'];
		$this->company_name = 		$wc_shipping['company'];
		$this->line_1 = 			$wc_shipping['address_1'];
		$this->line_2 = 			$wc_shipping['address_2'];
		$this->city = 				$wc_shipping['city'];
		$this->county = 			$wc_shipping['state'];
		$this->postcode = 			$wc_shipping['postcode'];
		$this->country = 			$wc_shipping['country'];
		$this->telephone = 			$phone;
		$this->email = 				$wc_billing['email'];
	} // End __construct ()

	public function toArray() {
		return array(
			'name' => $this->name(),
			'company_name' => $this->company_name(),
			'line_1' => $this->line_1(),
			'line_2' => $this->line_2(),
			'city' => $this->city(),
			'county' => $this->county(),
			'postcode' => $this->postcode(),
			'country' => $this->country(),
			'telephone' => $this->telephone(),
			'email' => $this->email(),
		);
	}

    /**
     * Gets the value of name.
     *
     * @return mixed
     */
    public function name() {
        return $this->name;
    }

    /**
     * Gets the value of company_name.
     *
     * @return mixed
     */
    public function company_name() {
        return $this->company_name;
    }

    /**
     * Gets the value of telephone.
     *
     * @return mixed
     */
    public function telephone() {
        return $this->telephone;
    }

    /**
     * Gets the value of email.
     *
     * @return mixed
     */
    public function email() {
        return $this->email;
    }

    /**
     * Gets the value of line_1.
     *
     * @return mixed
     */
    public function line_1() {
        return $this->line_1;
    }

    /**
     * Gets the value of line_2.
     *
     * @return mixed
     */
    public function line_2() {
        return $this->line_2;
    }

    /**
     * Gets the value of line_3.
     *
     * @return mixed
     */
    public function line_3() {
        return $this->line_3;
    }

    /**
     * Gets the value of city.
     *
     * @return mixed
     */
    public function city() {
        return $this->city;
    }

    /**
     * Gets the value of county.
     *
     * @return mixed
     */
    public function county() {
        return $this->county;
    }

    /**
     * Gets the value of postcode.
     *
     * @return mixed
     */
    public function postcode() {
        return $this->postcode;
    }

    /**
     * Gets the value of country.
     *
     * @return mixed
     */
    public function country() {
        return $this->country;
    }
}
