<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class WooCommerce_Shipmate_Parcel {

	protected $sender_reference = null;
	protected $weight = null;
	protected $length = null;
	protected $width = null;
	protected $depth = null;
	protected $value = null;
	protected $attributes = array();
    protected $hs_code = null;
    protected $short_description = null;
    protected $full_description = null; 
    protected $country_of_origin = null;
    protected $item_value = null;
    protected $item_quantity = null;
    protected $product_total_unit_value = null;
    protected $product_total_unit_weight = null;
    protected $sku_list = null;
    protected $items = array();

	/**
	 * Constructor function.
	 * @access  public
	 * @since   1.0.0
	 * @return  void
	 */
	public function __construct ($parcel_num, $order_id, $weight, $length, $width, $depth, $parcel_attributes = array(), $parcel_meta = array()) {
		$this->sender_reference = $order_id . '-' . $parcel_num;
		$this->value = 0;

        //Conversions kg to g and mm or m to cm
        if(get_option("_shipmate_weights_unit") == "g") {
            $this->weight = $weight;
        } else if(get_option("_shipmate_weights_unit") == "kg") {
            $this->weight = $weight * 1000;
        }

        if(get_option("_shipmate_dimensions_unit") == "cm") {
            $this->length = $length;
            $this->width = $width;
            $this->depth = $depth;
        } else if(get_option("_shipmate_dimensions_unit") == "mm") {
            $this->length = $length / 10;
            $this->width = $width / 10;
            $this->depth = $depth / 10;
        } else if(get_option("_shipmate_dimensions_unit") == "m") {
            $this->length = $length * 100;
            $this->width = $width * 100;
            $this->depth = $depth * 100;
        }

        $this->items = $parcel_meta;
        
        $this->attributes = $parcel_attributes;
        // $this->hs_code = $parcel_meta['hs_code'];
        // $this->short_description = $parcel_meta['short_description'];
        // $this->full_description = $parcel_meta['full_description'];
        // $this->country_of_origin = $parcel_meta['country_of_origin'];
        // $this->item_value = $parcel_meta['item_value'];
        // $this->item_quantity = $parcel_meta['item_quantity'];
        // $this->sku_list = $parcel_meta['sku_list'];

        // $this->product_total_unit_weight = $parcel_meta['product_weight'];
        // $this->product_total_unit_value = $parcel_meta['product_value'];
        $this->value = $parcel_meta['product_value'];
	} // End __construct ()

	public function toArray() {
		return array(
			'reference' => $this->sender_reference(),
			'value' => is_null($this->value()) ? 1 : $this->value(),
			'weight' => $this->weight(),
			'length' => $this->length(),
			'width' => $this->width(),
			'depth' => $this->depth(),
            'attributes' => $this->attributes(),
            'items' => $this->items(),
            // 'harmonised_code' => $this->hs_code(),
            // 'short_description' => $this->short_description(),
            // 'full_description' => $this->full_description(),
            // 'country_of_origin' => $this->country_of_origin(),
            // 'item_value' => $this->item_value(),
            // 'item_quantity' => $this->item_quantity(),
            // 'sku_list' => $this->sku_list()
		);
	}

    /**
     * Gets the value of sender_reference.
     *
     * @return mixed
     */
    public function sender_reference() {
        return $this->sender_reference;
    }

    /**
     * Gets the items of parcel.
     *
     * @return mixed
     */
    public function items() {
        return $this->items;
    }

    /**
     * Gets the value of weight.
     *
     * @return mixed
     */
    public function weight() {
        return $this->weight;
    }

    /**
     * Gets the value of length.
     *
     * @return mixed
     */
    public function length() {
        return $this->length;
    }

    /**
     * Gets the value of width.
     *
     * @return mixed
     */
    public function width() {
        return $this->width;
    }

    /**
     * Gets the value of depth.
     *
     * @return mixed
     */
    public function depth() {
        return $this->depth;
    }

    /**
     * Gets the value of value.
     *
     * @return mixed
     */
    public function value() {
        return $this->value;
    }

    /**
     * Gets the value of attributes.
     *
     * @return mixed
     */
    public function attributes() {
        return $this->attributes;
    }

    /**
     * Gets the value of product_name.
     *
     * @return mixed
     */
    public function product_name()
    {
        return $this->product_name;
    }

    /**
     * Gets the value of order_item_id.
     *
     * @return mixed
     */
    public function order_item_id()
    {
        return $this->order_item_id;
    }


    public function hs_code()
    {
        return $this->hs_code;
    }


    public function short_description()
    {
        return $this->short_description;
    }

    public function full_description()
    {
        return $this->full_description;
    }

    public function country_of_origin()
    {
        return $this->country_of_origin;
    }

    public function item_value()
    {
        return $this->item_value;
    }

    public function item_quantity()
    {
        return $this->item_quantity;
    }

    public function product_total_unit_value()
    {
        return $this->product_total_unit_value;
    }

    public function product_total_unit_weight()
    {
        return $this->product_total_unit_weight;
    }

    public function sku_list()
    {
        return $this->sku_list;
    }
}
